
# Slot: same as


holds between two entities that are considered equivalent to each other

URI: [biolink:same_as](https://w3id.org/biolink/vocab/same_as)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [exact match](exact_match.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | owl:sameAs |
|  | | skos:exactMatch |
|  | | WIKIDATA_PROPERTY:P2888 |
|  | | CHEMBL.MECHANISM:equivalent_to |
|  | | MONDO:equivalentTo |
| **Close Mappings:** | | owl:equivalentClass |
| **Narrow Mappings:** | | DRUGBANK:external-identifier |

